package wcswidth

import "unsafe"

const MAX_UNICODE = 1114111
const UNICODE_LIMIT = 1114112

type GraphemeBreakProperty uint8

const (
	GBP_AtStart GraphemeBreakProperty = iota
	GBP_None
	GBP_Prepend
	GBP_CR
	GBP_LF
	GBP_Control
	GBP_Extend
	GBP_Regional_Indicator
	GBP_SpacingMark
	GBP_L
	GBP_V
	GBP_T
	GBP_LV
	GBP_LVT
	GBP_ZWJ
	GBP_Private_Expecting_RI
)

type IndicConjunctBreak uint8

const (
	ICB_None IndicConjunctBreak = iota
	ICB_Linker
	ICB_Consonant
	ICB_Extend
)

type UnicodeCategory uint8

const (
	UC_Cn UnicodeCategory = iota
	UC_Cc
	UC_Zs
	UC_Po
	UC_Sc
	UC_Ps
	UC_Pe
	UC_Sm
	UC_Pd
	UC_Nd
	UC_Lu
	UC_Sk
	UC_Pc
	UC_Ll
	UC_So
	UC_Lo
	UC_Pi
	UC_Cf
	UC_No
	UC_Pf
	UC_Lt
	UC_Lm
	UC_Mn
	UC_Me
	UC_Mc
	UC_Nl
	UC_Zl
	UC_Zp
	UC_Cs
	UC_Co
)

// Total number of bits used: 23
type CharProps uint32

func (s CharProps) Is_extended_pictographic() uint8 {
	return uint8(s & 0b1)
}

func (s *CharProps) Set_is_extended_pictographic(val uint8) {
	*s &^= 0b1
	*s |= CharProps(val & 0b1)
}

func (s CharProps) Indic_conjunct_break() uint8 {
	return uint8((s >> 1) & 0b11)
}

func (s *CharProps) Set_indic_conjunct_break(val uint8) {
	*s &^= 0b11 << 1
	*s |= CharProps(val&0b11) << 1
}

func (s CharProps) Grapheme_break() uint8 {
	return uint8((s >> 3) & 0b1111)
}

func (s *CharProps) Set_grapheme_break(val uint8) {
	*s &^= 0b1111 << 3
	*s |= CharProps(val&0b1111) << 3
}

func (s CharProps) Is_punctuation() uint8 {
	return uint8((s >> 7) & 0b1)
}

func (s *CharProps) Set_is_punctuation(val uint8) {
	*s &^= 0b1 << 7
	*s |= CharProps(val&0b1) << 7
}

func (s CharProps) Is_word_char() uint8 {
	return uint8((s >> 8) & 0b1)
}

func (s *CharProps) Set_is_word_char(val uint8) {
	*s &^= 0b1 << 8
	*s |= CharProps(val&0b1) << 8
}

func (s CharProps) Is_combining_char() uint8 {
	return uint8((s >> 9) & 0b1)
}

func (s *CharProps) Set_is_combining_char(val uint8) {
	*s &^= 0b1 << 9
	*s |= CharProps(val&0b1) << 9
}

func (s CharProps) Is_symbol() uint8 {
	return uint8((s >> 10) & 0b1)
}

func (s *CharProps) Set_is_symbol(val uint8) {
	*s &^= 0b1 << 10
	*s |= CharProps(val&0b1) << 10
}

func (s CharProps) Is_non_rendered() uint8 {
	return uint8((s >> 11) & 0b1)
}

func (s *CharProps) Set_is_non_rendered(val uint8) {
	*s &^= 0b1 << 11
	*s |= CharProps(val&0b1) << 11
}

func (s CharProps) Is_invalid() uint8 {
	return uint8((s >> 12) & 0b1)
}

func (s *CharProps) Set_is_invalid(val uint8) {
	*s &^= 0b1 << 12
	*s |= CharProps(val&0b1) << 12
}

func (s CharProps) Is_emoji_presentation_base() uint8 {
	return uint8((s >> 13) & 0b1)
}

func (s *CharProps) Set_is_emoji_presentation_base(val uint8) {
	*s &^= 0b1 << 13
	*s |= CharProps(val&0b1) << 13
}

func (s CharProps) Category() uint8 {
	return uint8((s >> 14) & 0b11111)
}

func (s *CharProps) Set_category(val uint8) {
	*s &^= 0b11111 << 14
	*s |= CharProps(val&0b11111) << 14
}

func (s CharProps) Is_emoji() uint8 {
	return uint8((s >> 19) & 0b1)
}

func (s *CharProps) Set_is_emoji(val uint8) {
	*s &^= 0b1 << 19
	*s |= CharProps(val&0b1) << 19
}

func (s CharProps) Shifted_width() uint8 {
	return uint8((s >> 20) & 0b111)
}

func (s *CharProps) Set_shifted_width(val uint8) {
	*s &^= 0b111 << 20
	*s |= CharProps(val&0b111) << 20
}

// Total number of bits used: 10
type GraphemeSegmentationResult uint16

func (s GraphemeSegmentationResult) Grapheme_break() uint8 {
	return uint8(s & 0b1111)
}

func (s *GraphemeSegmentationResult) Set_grapheme_break(val uint8) {
	*s &^= 0b1111
	*s |= GraphemeSegmentationResult(val & 0b1111)
}

func (s GraphemeSegmentationResult) Incb_consonant_extended() uint8 {
	return uint8((s >> 4) & 0b1)
}

func (s *GraphemeSegmentationResult) Set_incb_consonant_extended(val uint8) {
	*s &^= 0b1 << 4
	*s |= GraphemeSegmentationResult(val&0b1) << 4
}

func (s GraphemeSegmentationResult) Incb_consonant_extended_linker() uint8 {
	return uint8((s >> 5) & 0b1)
}

func (s *GraphemeSegmentationResult) Set_incb_consonant_extended_linker(val uint8) {
	*s &^= 0b1 << 5
	*s |= GraphemeSegmentationResult(val&0b1) << 5
}

func (s GraphemeSegmentationResult) Incb_consonant_extended_linker_extended() uint8 {
	return uint8((s >> 6) & 0b1)
}

func (s *GraphemeSegmentationResult) Set_incb_consonant_extended_linker_extended(val uint8) {
	*s &^= 0b1 << 6
	*s |= GraphemeSegmentationResult(val&0b1) << 6
}

func (s GraphemeSegmentationResult) Emoji_modifier_sequence() uint8 {
	return uint8((s >> 7) & 0b1)
}

func (s *GraphemeSegmentationResult) Set_emoji_modifier_sequence(val uint8) {
	*s &^= 0b1 << 7
	*s |= GraphemeSegmentationResult(val&0b1) << 7
}

func (s GraphemeSegmentationResult) Emoji_modifier_sequence_before_last_char() uint8 {
	return uint8((s >> 8) & 0b1)
}

func (s *GraphemeSegmentationResult) Set_emoji_modifier_sequence_before_last_char(val uint8) {
	*s &^= 0b1 << 8
	*s |= GraphemeSegmentationResult(val&0b1) << 8
}

func (s GraphemeSegmentationResult) Add_to_current_cell() uint8 {
	return uint8((s >> 9) & 0b1)
}

func (s *GraphemeSegmentationResult) Set_add_to_current_cell(val uint8) {
	*s &^= 0b1 << 9
	*s |= GraphemeSegmentationResult(val&0b1) << 9
}

func (s CharProps) Width() int {
	return int(s.Shifted_width()) - 4
}

func (s CharProps) GraphemeSegmentationProperty() uint16 {
	return uint16(s.Grapheme_break() | (s.Indic_conjunct_break() << 4) | (s.Is_extended_pictographic() << 6))
}

func (r GraphemeSegmentationResult) State() (ans uint16) {
	return uint16(r) & 511
}

const charprops_mask = 255
const charprops_shift = 8

var charprops_t1 = [4352]uint8{
	0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 53, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 54, 52, 52, 52, 55, 21, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 62, 63, 64, 65, 66, 67, 68, 62, 63, 64, 65, 66, 67, 68, 62, 63, 64, 65, 66, 67, 68, 62, 63, 64, 65, 66, 67, 68, 62, 63, 64, 65, 66, 67, 68, 62, 69, 70, 70, 70, 70, 70, 70, 70, 70, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 52, 72, 73, 21, 74, 75, 76, 77, 78, 79, 80, 81, 82, 21, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 21, 21, 21, 108, 109, 110, 111, 111, 111, 111, 111, 111, 111, 111, 111, 112, 21, 21, 21, 21, 113, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 114, 21, 21, 115, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 116, 111, 111, 111, 111, 111, 111, 21, 21, 117, 118, 111, 119, 120, 121, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 122, 52, 52, 52, 52, 123, 124, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 125, 52, 126, 127, 111, 111, 111, 111, 111, 111, 111, 111, 111, 128, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 129, 40, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 40, 40, 140, 111, 111, 111, 111, 141, 142, 143, 144, 111, 145, 146, 111, 147, 148, 149, 111, 111, 150, 151, 152, 111, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 165, 165, 166, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 167, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 168, 169, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 170, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 171, 52, 52, 172, 173, 173, 173, 173, 173, 173, 173, 173, 173, 52, 52, 174, 173, 173, 173, 173, 175, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 176, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 177, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 173, 175, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 179, 180, 181, 181, 181, 181, 181, 181, 181, 181, 181, 181, 181, 181, 181, 181, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 178, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 182, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 182,
}
var charprops_t2 = [46848]uint8{
	0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 4, 5, 5, 6, 7, 5, 5, 5, 8, 9, 6, 10, 5, 11, 5, 5, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 5, 5, 10, 10, 10, 5, 5, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 8, 5, 9, 14, 15, 14, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 8, 10, 9, 10, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 4, 17, 7, 7, 18, 7, 19, 17, 20, 21, 22, 23, 10, 24, 25, 14, 26, 27, 28, 28, 20, 16, 17, 17, 20, 28, 22, 29, 28, 28, 28, 17, 13, 13, 13, 13, 13, 13, 30, 13, 13, 13, 13, 13, 13, 13, 13, 13, 30, 13, 13, 13, 13, 13, 13, 27, 30, 13, 13, 13, 13, 13, 30, 31, 31, 31, 16, 16, 16, 16, 31, 16, 31, 31, 31, 16, 31, 31, 16, 16, 31, 16, 31, 31, 16, 16, 16, 27, 31, 31, 31, 16, 31, 16, 31, 16, 13, 31, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 31, 13, 31, 13, 16, 13, 16, 13, 16, 13, 31, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 30, 31, 13, 16, 13, 31, 13, 16, 13, 16, 13, 31, 30, 31, 13, 16, 13, 16, 31, 13, 16, 13, 16, 13, 16, 30, 31, 30, 31, 13, 31, 13, 16, 13, 31, 31, 30, 31, 13, 31, 13, 16, 13, 16, 30, 31, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 30, 31, 13, 16, 13, 31, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 13, 16, 13, 16, 13, 16, 16, 16, 13, 13, 16, 13, 16, 13, 13, 16, 13, 13, 13, 16, 16, 13, 13, 13, 13, 16, 13, 13, 16, 13, 13, 13, 16, 16, 16, 13, 13, 16, 13, 13, 16, 13, 16, 13, 16, 13, 13, 16, 13, 16, 16, 13, 16, 13, 13, 16, 13, 13, 13, 16, 13, 16, 13, 13, 16, 16, 32, 13, 16, 16, 16, 32, 32, 32, 32, 13, 33, 16, 13, 33, 16, 13, 33, 16, 13, 31, 13, 31, 13, 31, 13, 31, 13, 31, 13, 31, 13, 31, 13, 31, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 13, 33, 16, 13, 16, 13, 13, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 16, 16, 16, 16, 16, 13, 13, 16, 13, 13, 16, 16, 13, 16, 13, 13, 13, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 31, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 31, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 32, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 14, 14, 20, 14, 34, 35, 34, 35, 35, 35, 34, 35, 34, 34, 35, 34, 14, 14, 14, 14, 14, 14, 20, 20, 20, 20, 14, 20, 14, 20, 34, 34, 34, 34, 34, 14, 14, 14, 14, 14, 14, 14, 34, 14, 34, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 37, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 13, 16, 13, 16, 34, 14, 13, 16, 38, 38, 34, 16, 16, 16, 5, 13, 38, 38, 38, 38, 14, 14, 13, 5, 13, 13, 13, 38, 13, 38, 13, 13, 16, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 38, 30, 30, 30, 30, 30, 30, 30, 13, 13, 16, 16, 16, 16, 16, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 16, 31, 31, 31, 31, 31, 31, 31, 16, 16, 16, 16, 16, 13, 16, 16, 13, 13, 13, 16, 16, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 16, 16, 16, 13, 16, 10, 13, 16, 13, 13, 16, 16, 13, 13, 13, 13, 30, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 16, 31, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 19, 36, 36, 36, 36, 36, 39, 39, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 38, 34, 5, 5, 5, 5, 5, 5, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 5, 11, 38, 38, 19, 19, 7, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 11, 36, 5, 36, 36, 5, 36, 36, 5, 36, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 32, 32, 32, 32, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 40, 40, 40, 40, 40, 40, 10, 10, 10, 5, 5, 7, 5, 5, 19, 19, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 5, 24, 5, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 5, 5, 5, 32, 32, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 5, 32, 36, 36, 36, 36, 36, 36, 36, 40, 19, 36, 36, 36, 36, 36, 36, 34, 34, 36, 36, 19, 36, 36, 36, 36, 32, 32, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 19, 19, 32, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 38, 40, 32, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 34, 34, 19, 5, 5, 5, 34, 38, 38, 36, 7, 7, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 34, 36, 36, 36, 36, 36, 36, 36, 36, 36, 34, 36, 36, 36, 34, 36, 36, 36, 36, 36, 38, 38, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 38, 38, 5, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 14, 32, 32, 32, 32, 32, 32, 38, 40, 40, 38, 38, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 40, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 36, 42, 36, 32, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 42, 42, 42, 42, 44, 42, 42, 32, 36, 36, 36, 36, 36, 36, 36, 43, 43, 43, 43, 43, 43, 43, 43, 32, 32, 36, 36, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 34, 32, 32, 32, 32, 32, 32, 43, 43, 43, 43, 43, 43, 43, 43, 32, 36, 42, 42, 38, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 38, 38, 32, 32, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 38, 43, 43, 43, 43, 43, 43, 43, 38, 43, 38, 38, 38, 43, 43, 43, 43, 38, 38, 36, 32, 45, 42, 42, 36, 36, 36, 36, 38, 38, 42, 42, 38, 38, 42, 42, 44, 32, 38, 38, 38, 38, 38, 38, 38, 38, 45, 38, 38, 38, 38, 43, 43, 38, 43, 32, 32, 36, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 43, 43, 7, 7, 46, 46, 46, 46, 46, 46, 19, 7, 32, 5, 36, 38, 38, 36, 36, 42, 38, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 32, 32, 38, 32, 32, 38, 38, 36, 38, 42, 42, 42, 36, 36, 38, 38, 38, 38, 36, 36, 38, 38, 36, 36, 36, 38, 38, 38, 36, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 38, 32, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 36, 36, 32, 32, 32, 36, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 42, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 38, 32, 32, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 38, 43, 43, 43, 43, 43, 43, 43, 38, 43, 43, 38, 43, 43, 43, 43, 43, 38, 38, 36, 32, 42, 42, 42, 36, 36, 36, 36, 36, 38, 36, 36, 42, 38, 42, 42, 44, 38, 38, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 36, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 7, 38, 38, 38, 38, 38, 38, 38, 43, 36, 36, 36, 36, 36, 36, 38, 36, 42, 42, 38, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 38, 38, 32, 32, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 38, 43, 43, 43, 43, 43, 43, 43, 38, 43, 43, 38, 43, 43, 43, 43, 43, 38, 38, 36, 32, 45, 36, 42, 36, 36, 36, 36, 38, 38, 42, 42, 38, 38, 42, 42, 44, 38, 38, 38, 38, 38, 38, 38, 36, 36, 45, 38, 38, 38, 38, 43, 43, 38, 43, 32, 32, 36, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 19, 43, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 32, 38, 32, 32, 32, 32, 32, 32, 38, 38, 38, 32, 32, 32, 38, 32, 32, 32, 32, 38, 38, 38, 32, 32, 38, 32, 38, 32, 32, 38, 38, 38, 32, 32, 38, 38, 38, 32, 32, 32, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 45, 42, 36, 42, 42, 38, 38, 38, 42, 42, 42, 38, 42, 42, 42, 36, 38, 38, 32, 38, 38, 38, 38, 38, 38, 45, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 46, 46, 46, 19, 19, 19, 19, 19, 19, 7, 19, 38, 38, 38, 38, 38, 36, 42, 42, 42, 36, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 38, 32, 32, 32, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 38, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 38, 38, 36, 32, 36, 36, 36, 42, 42, 42, 42, 38, 36, 36, 36, 38, 36, 36, 36, 44, 38, 38, 38, 38, 38, 38, 38, 36, 36, 38, 43, 43, 43, 38, 38, 32, 38, 38, 32, 32, 36, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 5, 46, 46, 46, 46, 46, 46, 46, 19, 32, 36, 42, 42, 5, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 38, 38, 36, 32, 42, 36, 45, 42, 45, 42, 42, 38, 36, 45, 45, 38, 45, 45, 36, 36, 38, 38, 38, 38, 38, 38, 38, 45, 45, 38, 38, 38, 38, 38, 38, 32, 32, 38, 32, 32, 36, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 32, 32, 42, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 42, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 38, 32, 32, 32, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 36, 36, 32, 45, 42, 42, 36, 36, 36, 36, 38, 42, 42, 42, 38, 42, 42, 42, 44, 47, 19, 38, 38, 38, 38, 32, 32, 32, 45, 46, 46, 46, 46, 46, 46, 46, 32, 32, 32, 36, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 46, 46, 46, 46, 46, 46, 46, 46, 46, 19, 32, 32, 32, 32, 32, 32, 38, 36, 42, 42, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 36, 38, 38, 38, 38, 45, 42, 42, 36, 36, 36, 38, 36, 38, 42, 42, 42, 42, 42, 42, 42, 45, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 42, 42, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 32, 48, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 7, 32, 32, 32, 32, 32, 32, 34, 36, 36, 36, 36, 36, 36, 36, 36, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 38, 32, 38, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 32, 48, 36, 36, 36, 36, 36, 36, 36, 36, 36, 32, 38, 38, 32, 32, 32, 32, 32, 38, 34, 38, 36, 36, 36, 36, 36, 36, 36, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 19, 19, 19, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 19, 5, 19, 19, 19, 36, 36, 19, 19, 19, 19, 19, 19, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 19, 36, 19, 36, 19, 36, 8, 9, 8, 9, 42, 42, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 36, 36, 36, 36, 36, 5, 36, 36, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 19, 19, 19, 19, 19, 19, 19, 19, 36, 19, 19, 19, 19, 19, 19, 38, 19, 19, 5, 5, 5, 5, 5, 19, 19, 19, 19, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 49, 49, 36, 36, 36, 36, 42, 36, 36, 36, 36, 36, 36, 49, 36, 36, 42, 42, 36, 36, 32, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 5, 5, 5, 5, 5, 32, 32, 32, 32, 32, 32, 42, 42, 36, 36, 32, 32, 32, 32, 36, 36, 36, 32, 49, 49, 49, 32, 32, 49, 49, 49, 49, 49, 49, 49, 32, 32, 32, 36, 36, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 49, 42, 36, 36, 49, 49, 49, 49, 49, 49, 36, 32, 49, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 49, 49, 49, 36, 19, 19, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 13, 38, 38, 38, 38, 38, 13, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 5, 34, 16, 16, 16, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 51, 52, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 38, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 38, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 36, 36, 36, 5, 5, 5, 5, 5, 5, 5, 5, 5, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 38, 16, 16, 16, 16, 16, 16, 38, 38, 11, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 19, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 4, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 8, 9, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 5, 5, 5, 55, 55, 55, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 45, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 45, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 38, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 37, 37, 42, 36, 36, 36, 36, 36, 36, 36, 42, 42, 42, 42, 42, 42, 42, 42, 36, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 5, 5, 5, 34, 5, 5, 5, 7, 32, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 5, 5, 5, 5, 5, 5, 11, 5, 5, 5, 5, 36, 36, 36, 24, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 32, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 36, 36, 36, 42, 42, 42, 42, 36, 36, 42, 42, 42, 38, 38, 38, 38, 42, 42, 36, 42, 42, 42, 42, 42, 42, 36, 36, 36, 38, 38, 38, 38, 19, 38, 38, 38, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 46, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 42, 42, 36, 38, 38, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 36, 42, 36, 36, 36, 36, 36, 36, 36, 38, 36, 49, 36, 49, 49, 36, 36, 36, 36, 36, 36, 36, 36, 42, 42, 42, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 5, 5, 5, 5, 5, 5, 5, 34, 5, 5, 5, 5, 5, 5, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 39, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 45, 36, 36, 36, 36, 36, 45, 36, 45, 42, 42, 42, 42, 36, 45, 45, 32, 32, 32, 32, 32, 32, 32, 32, 38, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 5, 5, 5, 5, 5, 5, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 36, 36, 36, 36, 36, 36, 36, 36, 36, 19, 19, 19, 19, 19, 19, 19, 19, 19, 5, 5, 5, 36, 36, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 36, 36, 36, 36, 42, 42, 36, 36, 45, 36, 36, 36, 32, 32, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 42, 36, 36, 42, 42, 42, 36, 42, 36, 36, 36, 45, 45, 38, 38, 38, 38, 38, 38, 38, 38, 5, 5, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 42, 42, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 42, 42, 36, 36, 38, 38, 38, 5, 5, 5, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 32, 32, 32, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 34, 34, 34, 34, 34, 5, 5, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 16, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 38, 13, 13, 13, 5, 5, 5, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 5, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 36, 36, 36, 36, 36, 36, 36, 32, 32, 32, 32, 36, 32, 32, 32, 32, 32, 32, 36, 32, 32, 42, 36, 36, 32, 38, 38, 38, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 34, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 38, 38, 13, 13, 13, 13, 13, 13, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 38, 38, 13, 13, 13, 13, 13, 13, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 38, 13, 38, 13, 38, 13, 38, 13, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 33, 33, 33, 33, 33, 33, 33, 33, 16, 16, 16, 16, 16, 16, 16, 16, 33, 33, 33, 33, 33, 33, 33, 33, 16, 16, 16, 16, 16, 16, 16, 16, 33, 33, 33, 33, 33, 33, 33, 33, 16, 16, 16, 16, 16, 38, 16, 16, 13, 13, 13, 13, 33, 14, 16, 14, 14, 14, 16, 16, 16, 38, 16, 16, 13, 13, 13, 13, 33, 14, 14, 14, 16, 16, 16, 16, 38, 38, 16, 16, 13, 13, 13, 13, 38, 14, 14, 14, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 14, 14, 14, 38, 38, 16, 16, 16, 38, 16, 16, 13, 13, 13, 13, 33, 14, 14, 38, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 24, 56, 57, 24, 24, 58, 11, 11, 58, 58, 58, 17, 5, 59, 60, 8, 23, 59, 60, 8, 23, 17, 17, 17, 5, 17, 17, 17, 17, 61, 62, 24, 24, 24, 24, 24, 4, 17, 5, 17, 17, 5, 17, 5, 5, 5, 23, 29, 17, 63, 5, 17, 15, 15, 5, 5, 5, 10, 8, 9, 5, 5, 63, 5, 5, 5, 5, 5, 5, 5, 5, 10, 5, 15, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 4, 24, 24, 24, 24, 24, 64, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 46, 34, 38, 38, 28, 46, 46, 46, 46, 46, 10, 10, 10, 8, 9, 35, 46, 28, 28, 28, 28, 46, 46, 46, 46, 46, 10, 10, 10, 8, 9, 38, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 38, 38, 38, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 18, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 39, 39, 39, 39, 36, 39, 39, 39, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 13, 26, 19, 26, 19, 13, 19, 26, 16, 13, 13, 13, 16, 16, 13, 13, 13, 31, 19, 13, 26, 19, 10, 13, 13, 13, 13, 13, 19, 19, 19, 26, 25, 19, 13, 19, 30, 19, 13, 19, 13, 30, 13, 13, 19, 16, 13, 13, 13, 13, 16, 32, 32, 32, 32, 65, 19, 19, 16, 16, 13, 13, 10, 10, 10, 10, 10, 13, 16, 16, 16, 16, 19, 10, 19, 19, 16, 19, 46, 46, 46, 28, 28, 46, 46, 46, 46, 46, 46, 28, 28, 28, 28, 46, 66, 66, 66, 66, 66, 66, 66, 66, 66, 66, 66, 66, 55, 55, 55, 55, 66, 66, 66, 66, 66, 66, 66, 66, 66, 66, 55, 55, 55, 55, 55, 55, 55, 55, 55, 13, 16, 55, 55, 55, 55, 28, 19, 19, 38, 38, 38, 38, 27, 27, 27, 27, 67, 25, 25, 25, 25, 25, 10, 10, 19, 19, 19, 19, 10, 19, 19, 10, 19, 19, 10, 19, 19, 21, 21, 19, 19, 19, 10, 19, 19, 19, 19, 19, 19, 19, 19, 19, 26, 26, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 10, 10, 19, 19, 27, 19, 27, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 26, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 27, 10, 27, 27, 10, 10, 10, 27, 27, 10, 10, 27, 10, 10, 10, 27, 10, 27, 10, 10, 10, 27, 10, 10, 10, 10, 27, 10, 10, 27, 27, 27, 27, 10, 10, 27, 10, 27, 10, 27, 27, 27, 27, 27, 27, 10, 27, 10, 10, 10, 10, 10, 27, 27, 27, 27, 10, 10, 10, 10, 27, 27, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 27, 10, 10, 10, 27, 10, 10, 10, 10, 10, 27, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 27, 27, 10, 10, 27, 27, 27, 27, 10, 10, 27, 27, 10, 10, 27, 27, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 27, 27, 10, 10, 27, 27, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 27, 10, 10, 10, 27, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 27, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 27, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 19, 19, 19, 19, 19, 19, 19, 19, 8, 9, 8, 9, 19, 19, 19, 19, 19, 19, 26, 19, 19, 19, 19, 19, 19, 19, 68, 68, 19, 19, 19, 19, 10, 10, 19, 19, 19, 19, 19, 19, 21, 69, 70, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 10, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 71, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 21, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 10, 10, 10, 10, 10, 10, 19, 19, 19, 19, 19, 19, 19, 68, 68, 68, 68, 21, 21, 21, 68, 21, 21, 68, 19, 19, 19, 19, 21, 21, 21, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 25, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 46, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 19, 19, 19, 19, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 19, 19, 26, 26, 26, 26, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 26, 26, 19, 26, 26, 26, 26, 26, 26, 26, 21, 21, 19, 19, 19, 19, 19, 19, 26, 26, 19, 19, 25, 27, 19, 19, 19, 19, 26, 26, 19, 19, 25, 27, 19, 19, 19, 19, 26, 26, 26, 19, 19, 26, 19, 19, 26, 26, 26, 26, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 26, 26, 26, 26, 19, 19, 19, 19, 19, 19, 19, 19, 19, 26, 19, 19, 19, 19, 19, 19, 19, 19, 10, 10, 10, 72, 72, 73, 73, 10, 21, 21, 21, 21, 21, 74, 26, 71, 71, 74, 71, 71, 71, 71, 25, 74, 71, 21, 71, 19, 68, 68, 71, 71, 21, 71, 71, 71, 74, 68, 74, 71, 21, 71, 21, 21, 71, 71, 21, 71, 71, 71, 21, 71, 71, 71, 21, 21, 75, 75, 75, 75, 75, 75, 75, 75, 21, 21, 21, 71, 71, 71, 71, 71, 25, 71, 25, 71, 71, 71, 71, 71, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 21, 25, 74, 71, 25, 74, 25, 21, 74, 25, 74, 74, 71, 74, 74, 71, 76, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 21, 71, 71, 21, 68, 71, 71, 71, 71, 71, 71, 19, 19, 19, 19, 77, 77, 77, 77, 77, 77, 71, 71, 21, 68, 21, 21, 21, 21, 71, 21, 71, 21, 21, 71, 74, 74, 21, 68, 71, 71, 71, 71, 71, 21, 71, 71, 68, 68, 71, 71, 71, 71, 21, 21, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 68, 68, 74, 71, 71, 71, 71, 68, 68, 74, 74, 25, 74, 74, 74, 74, 74, 68, 25, 74, 25, 74, 25, 68, 74, 74, 74, 74, 74, 74, 74, 74, 74, 74, 74, 74, 74, 71, 74, 71, 71, 71, 71, 74, 25, 68, 74, 74, 74, 74, 74, 25, 25, 68, 68, 25, 68, 74, 25, 25, 68, 68, 74, 74, 68, 74, 74, 71, 71, 21, 71, 71, 68, 19, 19, 21, 21, 68, 68, 68, 68, 71, 21, 71, 71, 21, 19, 21, 19, 21, 19, 19, 19, 19, 19, 19, 21, 19, 19, 19, 21, 19, 19, 19, 19, 19, 19, 68, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 21, 21, 19, 19, 19, 19, 19, 19, 19, 19, 26, 19, 19, 19, 19, 19, 19, 21, 19, 19, 21, 19, 19, 19, 19, 68, 19, 68, 19, 19, 19, 19, 68, 68, 68, 19, 68, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 21, 21, 71, 71, 71, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 19, 68, 68, 68, 19, 19, 19, 19, 19, 19, 19, 19, 19, 21, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 68, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 68, 10, 10, 10, 10, 10, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 72, 72, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8, 9, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 19, 19, 19, 19, 19, 21, 21, 21, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 68, 68, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 19, 19, 10, 10, 10, 10, 10, 10, 19, 19, 19, 68, 19, 19, 19, 19, 68, 26, 26, 26, 26, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 16, 13, 13, 13, 16, 16, 13, 16, 13, 16, 13, 16, 13, 13, 13, 13, 16, 13, 16, 16, 13, 16, 16, 16, 16, 16, 16, 34, 34, 13, 13, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 19, 19, 19, 19, 19, 19, 13, 16, 13, 16, 36, 36, 36, 13, 16, 38, 38, 38, 38, 38, 5, 5, 5, 5, 46, 5, 5, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 16, 38, 38, 38, 38, 38, 16, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 34, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 5, 5, 23, 29, 23, 29, 5, 5, 5, 23, 29, 5, 23, 29, 5, 5, 5, 5, 5, 5, 5, 5, 5, 11, 5, 5, 11, 5, 23, 29, 5, 5, 23, 29, 8, 9, 8, 9, 8, 9, 8, 9, 5, 5, 5, 5, 5, 34, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 11, 11, 5, 5, 5, 5, 11, 5, 8, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 19, 19, 5, 5, 5, 8, 9, 8, 9, 8, 9, 8, 9, 11, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 38, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 78, 79, 79, 79, 77, 80, 81, 82, 69, 70, 69, 70, 69, 70, 69, 70, 69, 70, 77, 77, 69, 70, 69, 70, 69, 70, 69, 70, 83, 69, 70, 70, 77, 82, 82, 82, 82, 82, 82, 82, 82, 82, 84, 84, 84, 84, 85, 85, 86, 80, 80, 80, 80, 80, 77, 77, 82, 82, 82, 80, 81, 87, 77, 19, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 38, 84, 84, 88, 88, 80, 80, 81, 83, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 79, 80, 80, 80, 81, 38, 38, 38, 38, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 89, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 77, 77, 90, 90, 90, 90, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 38, 38, 38, 38, 38, 38, 38, 38, 38, 77, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 38, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 28, 28, 28, 28, 28, 28, 28, 28, 77, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 68, 77, 68, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 80, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 38, 38, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 34, 34, 34, 34, 34, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 5, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 32, 36, 39, 39, 39, 5, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 5, 34, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 34, 34, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 36, 36, 5, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 34, 34, 34, 34, 34, 34, 34, 34, 34, 14, 14, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 16, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 34, 16, 16, 16, 16, 16, 16, 16, 16, 13, 16, 13, 16, 13, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 34, 14, 14, 13, 16, 13, 16, 32, 13, 16, 13, 16, 16, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 13, 13, 13, 13, 16, 13, 13, 13, 13, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 16, 13, 13, 13, 13, 16, 13, 16, 13, 13, 16, 38, 38, 13, 16, 38, 16, 38, 16, 13, 16, 13, 16, 13, 16, 13, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 34, 34, 34, 13, 16, 32, 34, 34, 16, 32, 32, 32, 32, 32, 32, 32, 36, 32, 32, 32, 36, 32, 32, 32, 32, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 36, 36, 42, 19, 19, 19, 19, 36, 38, 38, 38, 46, 46, 46, 46, 46, 46, 19, 19, 7, 19, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 42, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 32, 32, 32, 32, 32, 32, 5, 5, 5, 32, 5, 32, 32, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 45, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 5, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 50, 38, 38, 38, 36, 36, 36, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 42, 42, 36, 36, 36, 36, 42, 42, 36, 36, 42, 42, 45, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 38, 34, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 5, 5, 32, 32, 32, 32, 32, 36, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 42, 42, 36, 36, 42, 42, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 36, 32, 32, 32, 32, 32, 32, 32, 32, 36, 42, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 5, 5, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 32, 32, 32, 32, 32, 32, 19, 19, 19, 32, 49, 36, 49, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 32, 36, 36, 36, 32, 32, 36, 36, 32, 32, 32, 32, 32, 36, 36, 32, 36, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 34, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 36, 36, 42, 42, 5, 5, 32, 34, 34, 42, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 14, 34, 34, 34, 34, 16, 16, 16, 16, 16, 16, 16, 16, 16, 34, 14, 14, 38, 38, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 36, 42, 42, 36, 42, 42, 5, 42, 36, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 91, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 92, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 53, 38, 38, 38, 38, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 38, 38, 38, 38, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 93, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 16, 16, 16, 16, 16, 16, 16, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 16, 16, 16, 16, 16, 38, 38, 38, 38, 38, 32, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 10, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 38, 32, 38, 32, 32, 38, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 14, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 9, 8, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 19, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 7, 19, 19, 19, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 79, 79, 79, 79, 79, 79, 79, 69, 70, 79, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 79, 83, 83, 97, 97, 69, 70, 69, 70, 69, 70, 69, 70, 69, 70, 69, 70, 69, 70, 69, 70, 79, 79, 69, 70, 79, 79, 79, 79, 97, 97, 97, 79, 79, 79, 38, 79, 79, 79, 79, 83, 69, 70, 69, 70, 69, 70, 79, 79, 79, 98, 83, 98, 98, 98, 38, 79, 99, 79, 79, 38, 38, 38, 38, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 24, 38, 79, 79, 79, 99, 79, 79, 79, 69, 70, 79, 98, 79, 83, 79, 79, 100, 100, 100, 100, 100, 100, 100, 100, 100, 100, 79, 79, 98, 98, 98, 79, 79, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 101, 69, 79, 70, 88, 97, 88, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 102, 69, 98, 70, 98, 69, 70, 5, 8, 9, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 103, 103, 104, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 38, 38, 38, 99, 99, 98, 88, 77, 99, 99, 38, 19, 10, 10, 10, 10, 19, 19, 38, 64, 64, 64, 64, 64, 64, 64, 64, 64, 24, 24, 24, 19, 26, 96, 96, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 5, 5, 5, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 46, 46, 46, 46, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 46, 46, 19, 19, 19, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 55, 32, 32, 32, 32, 32, 32, 32, 32, 55, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 5, 55, 55, 55, 55, 55, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 38, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 5, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 13, 13, 13, 13, 13, 13, 13, 38, 13, 13, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 16, 16, 16, 16, 16, 16, 16, 38, 16, 16, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 34, 34, 34, 34, 34, 34, 38, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 38, 34, 34, 34, 34, 34, 34, 34, 34, 34, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 38, 38, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 38, 38, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 5, 46, 46, 46, 46, 46, 46, 46, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 19, 19, 46, 46, 46, 46, 46, 46, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 46, 46, 46, 46, 46, 38, 38, 38, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 46, 46, 32, 32, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 32, 36, 36, 36, 38, 36, 36, 38, 38, 38, 38, 38, 36, 36, 36, 36, 32, 32, 32, 32, 38, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 36, 36, 36, 38, 38, 38, 38, 36, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 5, 5, 5, 5, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 46, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 19, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 38, 38, 38, 38, 46, 46, 46, 46, 46, 5, 5, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 5, 5, 5, 5, 5, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 32, 32, 32, 34, 32, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 38, 38, 38, 36, 36, 36, 36, 36, 11, 34, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 38, 38, 38, 38, 38, 38, 38, 10, 10, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 36, 36, 11, 38, 38, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 32, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 46, 46, 46, 46, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 42, 36, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 5, 5, 5, 5, 5, 5, 5, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 36, 32, 32, 36, 36, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 36, 36, 36, 36, 42, 42, 36, 36, 5, 5, 40, 5, 5, 5, 5, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 40, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 36, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 42, 36, 36, 36, 36, 36, 36, 36, 36, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 5, 5, 5, 32, 42, 42, 32, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 5, 5, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 45, 32, 47, 47, 32, 5, 5, 5, 5, 36, 36, 36, 36, 5, 42, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 32, 5, 32, 5, 5, 5, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 36, 36, 36, 42, 42, 36, 45, 36, 36, 5, 5, 5, 5, 5, 5, 36, 32, 32, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 38, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 5, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 36, 36, 42, 42, 38, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 32, 32, 32, 32, 32, 38, 36, 36, 32, 45, 42, 36, 42, 42, 42, 42, 38, 38, 42, 42, 38, 38, 42, 42, 45, 38, 38, 32, 38, 38, 38, 38, 38, 38, 45, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 42, 42, 38, 38, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 38, 38, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 45, 42, 42, 36, 36, 36, 36, 36, 36, 38, 45, 38, 38, 45, 38, 45, 45, 45, 42, 38, 42, 42, 36, 45, 36, 47, 36, 32, 5, 5, 38, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 42, 42, 36, 36, 36, 42, 36, 32, 32, 32, 32, 5, 5, 5, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 5, 5, 38, 5, 36, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 45, 42, 42, 36, 36, 36, 36, 36, 36, 42, 36, 42, 42, 45, 42, 36, 36, 42, 36, 36, 32, 32, 5, 32, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 45, 42, 42, 36, 36, 36, 36, 38, 38, 42, 42, 42, 42, 36, 36, 42, 36, 36, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 32, 32, 32, 32, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 42, 42, 36, 42, 36, 36, 5, 5, 5, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 42, 36, 42, 42, 36, 36, 36, 36, 36, 36, 45, 36, 32, 5, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 36, 42, 36, 49, 49, 36, 36, 36, 36, 42, 36, 36, 36, 36, 36, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 46, 46, 5, 5, 5, 19, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 36, 36, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 45, 42, 42, 42, 42, 42, 38, 42, 42, 38, 38, 36, 36, 45, 36, 47, 42, 47, 42, 36, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 36, 36, 36, 36, 38, 38, 36, 36, 42, 42, 42, 42, 36, 32, 5, 32, 42, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 42, 47, 36, 36, 36, 36, 5, 5, 5, 5, 5, 5, 5, 5, 36, 38, 38, 38, 38, 38, 38, 38, 38, 32, 36, 36, 36, 36, 36, 36, 42, 42, 36, 36, 36, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 47, 47, 47, 47, 47, 47, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 36, 36, 5, 5, 5, 32, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 36, 36, 36, 36, 36, 36, 36, 38, 36, 36, 36, 36, 36, 36, 42, 36, 32, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 42, 36, 36, 36, 36, 36, 36, 36, 42, 36, 36, 42, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 38, 38, 38, 36, 38, 36, 36, 38, 36, 36, 36, 36, 36, 36, 36, 47, 36, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 42, 42, 42, 38, 36, 36, 38, 42, 42, 36, 42, 36, 32, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 42, 42, 5, 5, 38, 38, 38, 38, 38, 38, 38, 36, 36, 47, 42, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 42, 42, 36, 36, 36, 36, 36, 38, 38, 38, 42, 42, 36, 45, 36, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 19, 19, 19, 19, 19, 19, 19, 19, 7, 7, 7, 7, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 38, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 36, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 42, 42, 42, 36, 36, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 5, 5, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 36, 36, 36, 36, 36, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 36, 36, 36, 5, 5, 5, 5, 5, 19, 19, 19, 19, 34, 34, 34, 34, 5, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 46, 46, 46, 46, 46, 46, 46, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 34, 34, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 53, 32, 32, 32, 53, 53, 53, 53, 34, 34, 5, 5, 5, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 36, 32, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 42, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 80, 80, 79, 80, 84, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 85, 85, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 38, 38, 38, 38, 38, 38, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 80, 80, 80, 80, 38, 80, 80, 80, 80, 80, 80, 80, 38, 80, 80, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 81, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 81, 81, 81, 38, 38, 81, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 81, 81, 81, 81, 38, 38, 38, 38, 38, 38, 38, 38, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 19, 36, 36, 5, 24, 24, 24, 24, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 45, 45, 36, 36, 36, 19, 19, 19, 45, 45, 45, 45, 45, 45, 24, 24, 24, 24, 24, 24, 24, 24, 36, 36, 36, 36, 36, 36, 36, 36, 19, 19, 36, 36, 36, 36, 36, 36, 36, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 36, 36, 36, 36, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 36, 36, 36, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 38, 38, 38, 38, 38, 38, 38, 38, 38, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 38, 13, 13, 38, 38, 13, 38, 38, 13, 13, 38, 38, 13, 13, 13, 13, 38, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 38, 16, 38, 16, 16, 16, 16, 16, 16, 16, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 38, 13, 13, 13, 13, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 38, 13, 13, 13, 13, 13, 13, 13, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 38, 13, 13, 13, 13, 38, 13, 13, 13, 13, 13, 38, 13, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 10, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 10, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 10, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 10, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 10, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 10, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 10, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 10, 16, 16, 16, 16, 16, 16, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 10, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 10, 16, 16, 16, 16, 16, 16, 13, 16, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 19, 19, 19, 19, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 19, 19, 19, 19, 19, 19, 19, 19, 36, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 36, 19, 19, 5, 5, 5, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 36, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 32, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 38, 38, 38, 38, 38, 38, 16, 16, 16, 16, 16, 16, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 38, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 38, 38, 36, 36, 36, 36, 36, 36, 36, 38, 36, 36, 38, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 36, 36, 36, 36, 36, 36, 36, 34, 34, 34, 34, 34, 34, 34, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 32, 19, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 36, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 7, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 36, 36, 36, 36, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 36, 36, 32, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 36, 36, 36, 36, 36, 36, 36, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 36, 36, 36, 36, 36, 36, 36, 34, 38, 38, 38, 38, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 5, 5, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 19, 46, 46, 46, 7, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 19, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 38, 32, 38, 38, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 32, 38, 32, 38, 38, 38, 38, 38, 38, 32, 38, 38, 38, 38, 32, 38, 32, 38, 32, 38, 32, 32, 32, 38, 32, 32, 38, 32, 38, 38, 32, 38, 32, 38, 32, 38, 32, 38, 32, 38, 32, 32, 38, 32, 38, 38, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 32, 32, 32, 32, 38, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 32, 32, 32, 38, 32, 32, 32, 32, 32, 38, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 10, 10, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 71, 71, 71, 71, 68, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 105, 105, 105, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 105, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 68, 105, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 46, 46, 71, 71, 71, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 19, 71, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 19, 19, 71, 71, 71, 71, 25, 25, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 25, 25, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 68, 26, 26, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 71, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 106, 77, 68, 68, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 68, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 68, 77, 77, 68, 68, 68, 68, 68, 68, 68, 68, 68, 77, 105, 105, 105, 105, 77, 77, 77, 77, 77, 77, 77, 77, 77, 105, 105, 105, 105, 105, 105, 105, 68, 68, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 75, 75, 75, 75, 75, 75, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 21, 71, 71, 21, 21, 21, 21, 21, 21, 21, 21, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 71, 71, 21, 21, 71, 21, 21, 21, 71, 71, 21, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 21, 21, 68, 68, 68, 68, 68, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 71, 71, 21, 68, 21, 71, 21, 68, 68, 68, 107, 107, 107, 107, 107, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 21, 68, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 21, 71, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 19, 19, 19, 19, 19, 19, 19, 19, 71, 71, 71, 21, 21, 68, 68, 68, 68, 71, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 71, 71, 71, 71, 71, 71, 71, 21, 21, 71, 71, 21, 68, 68, 21, 21, 21, 21, 68, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 21, 71, 71, 21, 21, 21, 21, 71, 71, 68, 71, 71, 71, 71, 68, 68, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 68, 21, 71, 71, 21, 71, 71, 71, 71, 71, 71, 71, 71, 21, 21, 71, 71, 71, 71, 71, 71, 71, 71, 71, 21, 71, 71, 71, 71, 71, 21, 21, 21, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 21, 21, 21, 71, 71, 71, 71, 71, 71, 71, 71, 21, 21, 21, 71, 71, 21, 71, 21, 71, 71, 71, 71, 21, 71, 71, 71, 71, 71, 71, 21, 71, 71, 71, 21, 71, 71, 71, 71, 71, 71, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 71, 71, 71, 71, 71, 21, 68, 21, 21, 21, 68, 68, 68, 71, 71, 68, 68, 68, 105, 105, 105, 105, 68, 68, 68, 68, 21, 21, 21, 21, 21, 21, 71, 71, 71, 21, 71, 68, 68, 105, 105, 105, 21, 71, 71, 21, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 71, 71, 71, 105, 105, 105, 105, 71, 71, 71, 71, 71, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 71, 71, 71, 71, 71, 105, 105, 105, 105, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 105, 105, 68, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 105, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 105, 105, 105, 105, 105, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 105, 105, 105, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 105, 105, 105, 105, 105, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 105, 105, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 105, 105, 105, 71, 71, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 19, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 19, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 71, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 105, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 105, 105, 105, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 105, 105, 105, 105, 68, 68, 68, 68, 68, 68, 68, 68, 68, 105, 105, 105, 105, 105, 105, 105, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 38, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 38, 38, 38, 38, 38, 38, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 105, 96, 96, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 96, 96, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 38, 96, 96, 64, 24, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 108, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 36, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 94, 96, 96,
}
var charprops_t3 = [109]CharProps{
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Control) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((1 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),            // 0
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Control) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((1 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((3 & 0b111) << 20),            // 1
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_LF) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((1 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((3 & 0b111) << 20),                 // 2
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_CR) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((1 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((3 & 0b111) << 20),                 // 3
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Zs) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 4
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Po) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 5
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Po) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((5 & 0b111) << 20),               // 6
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 7
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Ps) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 8
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pe) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 9
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 10
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pd) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 11
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Nd) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((5 & 0b111) << 20),               // 12
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lu) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 13
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sk) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 14
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 15
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Ll) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 16
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Po) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 17
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 18
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 19
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sk) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 20
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((5 & 0b111) << 20),               // 21
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 22
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pi) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 23
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Control) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cf) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),            // 24
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((2 & 0b111) << 20),               // 25
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 26
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 27
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_No) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 28
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pf) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 29
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lu) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 30
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Ll) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 31
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 32
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lt) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 33
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 34
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 35
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),           // 36
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),           // 37
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((0 & 0b111) << 20),               // 38
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Me) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),           // 39
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Prepend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cf) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),            // 40
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Nd) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 41
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_SpacingMark) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),        // 42
	((0 & 0b1) << 0) | ((CharProps(ICB_Consonant) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),          // 43
	((0 & 0b1) << 0) | ((CharProps(ICB_Linker) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),           // 44
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),           // 45
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_No) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 46
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Prepend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),            // 47
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_SpacingMark) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),        // 48
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),               // 49
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_L) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),                  // 50
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_L) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),                  // 51
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_V) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),                  // 52
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_V) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),                  // 53
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_T) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),                  // 54
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Nl) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 55
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cf) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),             // 56
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_ZWJ) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cf) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),              // 57
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pd) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 58
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pi) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 59
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pf) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 60
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Control) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Zl) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),            // 61
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Control) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Zp) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),            // 62
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Po) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((5 & 0b111) << 20),               // 63
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Control) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),            // 64
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Ll) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((5 & 0b111) << 20),               // 65
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Nl) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 66
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Sm) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((2 & 0b111) << 20),               // 67
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((6 & 0b111) << 20),               // 68
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Ps) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 69
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pe) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 70
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),               // 71
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Sm) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((5 & 0b111) << 20),               // 72
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Sm) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((6 & 0b111) << 20),               // 73
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 74
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 75
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 76
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 77
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Zs) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 78
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Po) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 79
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 80
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 81
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Nl) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 82
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pd) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 83
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),           // 84
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Mc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),           // 85
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Pd) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((6 & 0b111) << 20),               // 86
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Po) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((6 & 0b111) << 20),               // 87
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sk) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 88
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 89
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_No) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 90
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_LV) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),                 // 91
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_LVT) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),                // 92
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((1 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cs) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((3 & 0b111) << 20),               // 93
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Co) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((2 & 0b111) << 20),               // 94
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 95
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((1 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((3 & 0b111) << 20),               // 96
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Pc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 97
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 98
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Sc) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 99
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Nd) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 100
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lu) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 101
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Ll) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((6 & 0b111) << 20),               // 102
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lm) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((5 & 0b111) << 20),           // 103
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Lo) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),               // 104
	((1 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_None) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9) | ((0 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cn) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((0 & 0b111) << 20),               // 105
	((0 & 0b1) << 0) | ((CharProps(ICB_None) & 0b11) << 1) | ((CharProps(GBP_Regional_Indicator) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_So) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((6 & 0b111) << 20), // 106
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((1 & 0b1) << 10) | ((0 & 0b1) << 11) | ((0 & 0b1) << 12) | ((1 & 0b1) << 13) | ((CharProps(UC_Sk) & 0b11111) << 14) | ((1 & 0b1) << 19) | ((6 & 0b111) << 20),           // 107
	((0 & 0b1) << 0) | ((CharProps(ICB_Extend) & 0b11) << 1) | ((CharProps(GBP_Extend) & 0b1111) << 3) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9) | ((0 & 0b1) << 10) | ((1 & 0b1) << 11) | ((0 & 0b1) << 12) | ((0 & 0b1) << 13) | ((CharProps(UC_Cf) & 0b11111) << 14) | ((0 & 0b1) << 19) | ((4 & 0b111) << 20),           // 108
}

// Array accessor function that avoids bounds checking
func charprops_for(x uint32) CharProps {
	t1 := uintptr(*(*uint8)(unsafe.Pointer(uintptr(unsafe.Pointer(&charprops_t1[0])) + uintptr(x>>charprops_shift)*1)))
	t1_shifted := (t1 << charprops_shift) + (uintptr(x) & charprops_mask)
	t2 := uintptr(*(*uint8)(unsafe.Pointer(uintptr(unsafe.Pointer(&charprops_t2[0])) + t1_shifted*1)))
	return *(*CharProps)(unsafe.Pointer(uintptr(unsafe.Pointer(&charprops_t3[0])) + t2*4))
}

const graphemesegmentationresult_mask = 15
const graphemesegmentationresult_shift = 4

var graphemesegmentationresult_t1 = [4096]uint8{
	0, 0, 1, 0, 2, 2, 3, 2, 4, 4, 5, 4, 6, 6, 7, 6, 8, 8, 9, 8, 10, 10, 11, 10, 12, 12, 13, 12, 14, 14, 15, 14, 16, 16, 17, 16, 18, 18, 19, 18, 16, 16, 17, 16, 18, 18, 19, 18, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 20, 20, 21, 20, 22, 22, 23, 22, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 4, 4, 5, 4, 6, 6, 7, 6, 32, 32, 33, 32, 34, 34, 35, 34, 0, 36, 1, 1, 2, 37, 3, 3, 4, 38, 5, 5, 6, 39, 7, 7, 8, 40, 9, 9, 10, 41, 11, 11, 12, 42, 13, 13, 14, 43, 15, 15, 16, 44, 17, 17, 18, 45, 19, 19, 16, 44, 17, 17, 18, 45, 19, 19, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 20, 46, 21, 21, 22, 47, 23, 23, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 4, 38, 5, 5, 6, 39, 7, 7, 32, 52, 33, 33, 34, 53, 35, 35, 0, 0, 1, 0, 2, 2, 3, 2, 4, 4, 5, 4, 6, 6, 7, 6, 8, 8, 9, 8, 10, 10, 11, 10, 12, 12, 13, 12, 14, 14, 15, 14, 16, 16, 17, 16, 18, 18, 19, 18, 16, 16, 17, 16, 18, 18, 19, 18, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 20, 20, 21, 20, 22, 22, 23, 22, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 4, 4, 5, 4, 6, 6, 7, 6, 32, 32, 33, 32, 34, 34, 35, 34, 0, 36, 1, 1, 2, 37, 3, 3, 4, 38, 5, 5, 6, 39, 7, 7, 8, 40, 9, 9, 10, 41, 11, 11, 12, 42, 13, 13, 14, 43, 15, 15, 16, 44, 17, 17, 18, 45, 19, 19, 16, 44, 17, 17, 18, 45, 19, 19, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 20, 46, 21, 21, 22, 47, 23, 23, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 4, 38, 5, 5, 6, 39, 7, 7, 32, 52, 33, 33, 34, 53, 35, 35, 0, 54, 1, 54, 2, 55, 3, 55, 4, 56, 9, 56, 6, 57, 11, 57, 8, 58, 9, 58, 10, 59, 11, 59, 12, 60, 13, 60, 14, 61, 15, 61, 16, 62, 17, 62, 18, 63, 19, 63, 16, 62, 17, 62, 18, 63, 19, 63, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 20, 64, 9, 64, 22, 65, 11, 65, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 4, 56, 9, 56, 6, 57, 11, 57, 32, 70, 9, 70, 34, 71, 11, 71, 0, 36, 1, 72, 2, 37, 3, 73, 4, 38, 9, 74, 6, 39, 11, 75, 8, 40, 9, 76, 10, 41, 11, 77, 12, 42, 13, 78, 14, 43, 15, 79, 16, 44, 17, 80, 18, 45, 19, 81, 16, 44, 17, 80, 18, 45, 19, 81, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 20, 46, 9, 82, 22, 47, 11, 83, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 4, 38, 9, 74, 6, 39, 11, 75, 32, 52, 9, 88, 34, 53, 11, 89, 0, 54, 1, 54, 2, 55, 3, 55, 4, 56, 9, 56, 6, 57, 11, 57, 8, 58, 9, 58, 10, 59, 11, 59, 12, 60, 13, 60, 14, 61, 15, 61, 16, 62, 17, 62, 18, 63, 19, 63, 16, 62, 17, 62, 18, 63, 19, 63, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 20, 64, 9, 64, 22, 65, 11, 65, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 4, 56, 9, 56, 6, 57, 11, 57, 32, 70, 9, 70, 34, 71, 11, 71, 0, 36, 1, 72, 2, 37, 3, 73, 4, 38, 9, 74, 6, 39, 11, 75, 8, 40, 9, 76, 10, 41, 11, 77, 12, 42, 13, 78, 14, 43, 15, 79, 16, 44, 17, 80, 18, 45, 19, 81, 16, 44, 17, 80, 18, 45, 19, 81, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 20, 46, 9, 82, 22, 47, 11, 83, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 4, 38, 9, 74, 6, 39, 11, 75, 32, 52, 9, 88, 34, 53, 11, 89, 90, 90, 91, 90, 92, 92, 93, 92, 94, 94, 95, 94, 96, 96, 97, 96, 98, 98, 99, 98, 100, 100, 101, 100, 102, 102, 103, 102, 104, 104, 105, 104, 106, 106, 107, 106, 108, 108, 109, 108, 106, 106, 107, 106, 108, 108, 109, 108, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 110, 110, 111, 110, 112, 112, 113, 112, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 94, 94, 95, 94, 96, 96, 97, 96, 122, 122, 123, 122, 124, 124, 125, 124, 90, 126, 91, 91, 92, 127, 93, 93, 94, 128, 95, 95, 96, 129, 97, 97, 98, 130, 99, 99, 100, 131, 101, 101, 102, 132, 103, 103, 104, 133, 105, 105, 106, 134, 107, 107, 108, 135, 109, 109, 106, 134, 107, 107, 108, 135, 109, 109, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 110, 136, 111, 111, 112, 137, 113, 113, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 94, 128, 95, 95, 96, 129, 97, 97, 122, 142, 123, 123, 124, 143, 125, 125, 90, 90, 91, 90, 92, 92, 93, 92, 94, 94, 95, 94, 96, 96, 97, 96, 98, 98, 99, 98, 100, 100, 101, 100, 102, 102, 103, 102, 104, 104, 105, 104, 106, 106, 107, 106, 108, 108, 109, 108, 106, 106, 107, 106, 108, 108, 109, 108, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 110, 110, 111, 110, 112, 112, 113, 112, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 94, 94, 95, 94, 96, 96, 97, 96, 122, 122, 123, 122, 124, 124, 125, 124, 90, 126, 91, 91, 92, 127, 93, 93, 94, 128, 95, 95, 96, 129, 97, 97, 98, 130, 99, 99, 100, 131, 101, 101, 102, 132, 103, 103, 104, 133, 105, 105, 106, 134, 107, 107, 108, 135, 109, 109, 106, 134, 107, 107, 108, 135, 109, 109, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 110, 136, 111, 111, 112, 137, 113, 113, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 94, 128, 95, 95, 96, 129, 97, 97, 122, 142, 123, 123, 124, 143, 125, 125, 90, 144, 91, 144, 92, 145, 93, 145, 94, 146, 99, 146, 96, 147, 101, 147, 98, 148, 99, 148, 100, 149, 101, 149, 102, 150, 103, 150, 104, 151, 105, 151, 106, 152, 107, 152, 108, 153, 109, 153, 106, 152, 107, 152, 108, 153, 109, 153, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 110, 154, 99, 154, 112, 155, 101, 155, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 94, 146, 99, 146, 96, 147, 101, 147, 122, 160, 99, 160, 124, 161, 101, 161, 90, 126, 91, 162, 92, 127, 93, 163, 94, 128, 99, 164, 96, 129, 101, 165, 98, 130, 99, 166, 100, 131, 101, 167, 102, 132, 103, 168, 104, 133, 105, 169, 106, 134, 107, 170, 108, 135, 109, 171, 106, 134, 107, 170, 108, 135, 109, 171, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 110, 136, 99, 172, 112, 137, 101, 173, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 94, 128, 99, 164, 96, 129, 101, 165, 122, 142, 99, 178, 124, 143, 101, 179, 90, 144, 91, 144, 92, 145, 93, 145, 94, 146, 99, 146, 96, 147, 101, 147, 98, 148, 99, 148, 100, 149, 101, 149, 102, 150, 103, 150, 104, 151, 105, 151, 106, 152, 107, 152, 108, 153, 109, 153, 106, 152, 107, 152, 108, 153, 109, 153, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 110, 154, 99, 154, 112, 155, 101, 155, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 94, 146, 99, 146, 96, 147, 101, 147, 122, 160, 99, 160, 124, 161, 101, 161, 90, 126, 91, 162, 92, 127, 93, 163, 94, 128, 99, 164, 96, 129, 101, 165, 98, 130, 99, 166, 100, 131, 101, 167, 102, 132, 103, 168, 104, 133, 105, 169, 106, 134, 107, 170, 108, 135, 109, 171, 106, 134, 107, 170, 108, 135, 109, 171, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 110, 136, 99, 172, 112, 137, 101, 173, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 94, 128, 99, 164, 96, 129, 101, 165, 122, 142, 99, 178, 124, 143, 101, 179, 0, 0, 1, 0, 2, 2, 3, 2, 4, 4, 5, 4, 6, 6, 7, 6, 8, 8, 9, 8, 10, 10, 11, 10, 12, 12, 13, 12, 14, 14, 15, 14, 16, 16, 17, 16, 18, 18, 19, 18, 16, 16, 17, 16, 18, 18, 19, 18, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 20, 20, 21, 20, 22, 22, 23, 22, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 4, 4, 5, 4, 10, 10, 11, 10, 32, 32, 33, 32, 34, 34, 35, 34, 0, 36, 1, 1, 2, 37, 3, 3, 4, 38, 5, 5, 6, 39, 7, 7, 8, 40, 9, 9, 10, 41, 11, 11, 12, 42, 13, 13, 14, 43, 15, 15, 16, 44, 17, 17, 18, 45, 19, 19, 16, 44, 17, 17, 18, 45, 19, 19, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 20, 46, 21, 21, 22, 47, 23, 23, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 4, 38, 5, 5, 10, 41, 11, 11, 32, 52, 33, 33, 34, 53, 35, 35, 0, 0, 1, 0, 2, 2, 3, 2, 4, 4, 5, 4, 6, 6, 7, 6, 8, 8, 9, 8, 10, 10, 11, 10, 12, 12, 13, 12, 14, 14, 15, 14, 16, 16, 17, 16, 18, 18, 19, 18, 16, 16, 17, 16, 18, 18, 19, 18, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 4, 4, 5, 4, 6, 6, 7, 6, 20, 20, 21, 20, 22, 22, 23, 22, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 24, 24, 25, 24, 26, 26, 27, 26, 28, 28, 29, 28, 30, 30, 31, 30, 4, 4, 5, 4, 10, 10, 11, 10, 32, 32, 33, 32, 34, 34, 35, 34, 0, 36, 1, 1, 2, 37, 3, 3, 4, 38, 5, 5, 6, 39, 7, 7, 8, 40, 9, 9, 10, 41, 11, 11, 12, 42, 13, 13, 14, 43, 15, 15, 16, 44, 17, 17, 18, 45, 19, 19, 16, 44, 17, 17, 18, 45, 19, 19, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 4, 38, 5, 5, 6, 39, 7, 7, 20, 46, 21, 21, 22, 47, 23, 23, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 24, 48, 25, 25, 26, 49, 27, 27, 28, 50, 29, 29, 30, 51, 31, 31, 4, 38, 5, 5, 10, 41, 11, 11, 32, 52, 33, 33, 34, 53, 35, 35, 0, 54, 1, 54, 2, 55, 3, 55, 4, 56, 9, 56, 6, 57, 11, 57, 8, 58, 9, 58, 10, 59, 11, 59, 12, 60, 13, 60, 14, 61, 15, 61, 16, 62, 17, 62, 18, 63, 19, 63, 16, 62, 17, 62, 18, 63, 19, 63, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 20, 64, 9, 64, 22, 65, 11, 65, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 4, 56, 9, 56, 10, 59, 11, 59, 32, 70, 9, 70, 34, 71, 11, 71, 0, 36, 1, 72, 2, 37, 3, 73, 4, 38, 9, 74, 6, 39, 11, 75, 8, 40, 9, 76, 10, 41, 11, 77, 12, 42, 13, 78, 14, 43, 15, 79, 16, 44, 17, 80, 18, 45, 19, 81, 16, 44, 17, 80, 18, 45, 19, 81, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 20, 46, 9, 82, 22, 47, 11, 83, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 4, 38, 9, 74, 10, 41, 11, 77, 32, 52, 9, 88, 34, 53, 11, 89, 0, 54, 1, 54, 2, 55, 3, 55, 4, 56, 9, 56, 6, 57, 11, 57, 8, 58, 9, 58, 10, 59, 11, 59, 12, 60, 13, 60, 14, 61, 15, 61, 16, 62, 17, 62, 18, 63, 19, 63, 16, 62, 17, 62, 18, 63, 19, 63, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 4, 56, 9, 56, 6, 57, 11, 57, 20, 64, 9, 64, 22, 65, 11, 65, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 24, 66, 9, 66, 26, 67, 11, 67, 28, 68, 9, 68, 30, 69, 11, 69, 4, 56, 9, 56, 10, 59, 11, 59, 32, 70, 9, 70, 34, 71, 11, 71, 0, 36, 1, 72, 2, 37, 3, 73, 4, 38, 9, 74, 6, 39, 11, 75, 8, 40, 9, 76, 10, 41, 11, 77, 12, 42, 13, 78, 14, 43, 15, 79, 16, 44, 17, 80, 18, 45, 19, 81, 16, 44, 17, 80, 18, 45, 19, 81, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 4, 38, 9, 74, 6, 39, 11, 75, 20, 46, 9, 82, 22, 47, 11, 83, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 24, 48, 9, 84, 26, 49, 11, 85, 28, 50, 9, 86, 30, 51, 11, 87, 4, 38, 9, 74, 10, 41, 11, 77, 32, 52, 9, 88, 34, 53, 11, 89, 90, 90, 91, 90, 92, 92, 93, 92, 94, 94, 95, 94, 96, 96, 97, 96, 98, 98, 99, 98, 100, 100, 101, 100, 102, 102, 103, 102, 104, 104, 105, 104, 106, 106, 107, 106, 108, 108, 109, 108, 106, 106, 107, 106, 108, 108, 109, 108, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 110, 110, 111, 110, 112, 112, 113, 112, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 94, 94, 95, 94, 100, 100, 101, 100, 122, 122, 123, 122, 124, 124, 125, 124, 90, 126, 91, 91, 92, 127, 93, 93, 94, 128, 95, 95, 96, 129, 97, 97, 98, 130, 99, 99, 100, 131, 101, 101, 102, 132, 103, 103, 104, 133, 105, 105, 106, 134, 107, 107, 108, 135, 109, 109, 106, 134, 107, 107, 108, 135, 109, 109, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 110, 136, 111, 111, 112, 137, 113, 113, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 94, 128, 95, 95, 100, 131, 101, 101, 122, 142, 123, 123, 124, 143, 125, 125, 90, 90, 91, 90, 92, 92, 93, 92, 94, 94, 95, 94, 96, 96, 97, 96, 98, 98, 99, 98, 100, 100, 101, 100, 102, 102, 103, 102, 104, 104, 105, 104, 106, 106, 107, 106, 108, 108, 109, 108, 106, 106, 107, 106, 108, 108, 109, 108, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 94, 94, 95, 94, 96, 96, 97, 96, 110, 110, 111, 110, 112, 112, 113, 112, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 114, 114, 115, 114, 116, 116, 117, 116, 118, 118, 119, 118, 120, 120, 121, 120, 94, 94, 95, 94, 100, 100, 101, 100, 122, 122, 123, 122, 124, 124, 125, 124, 90, 126, 91, 91, 92, 127, 93, 93, 94, 128, 95, 95, 96, 129, 97, 97, 98, 130, 99, 99, 100, 131, 101, 101, 102, 132, 103, 103, 104, 133, 105, 105, 106, 134, 107, 107, 108, 135, 109, 109, 106, 134, 107, 107, 108, 135, 109, 109, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 94, 128, 95, 95, 96, 129, 97, 97, 110, 136, 111, 111, 112, 137, 113, 113, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 114, 138, 115, 115, 116, 139, 117, 117, 118, 140, 119, 119, 120, 141, 121, 121, 94, 128, 95, 95, 100, 131, 101, 101, 122, 142, 123, 123, 124, 143, 125, 125, 90, 144, 91, 144, 92, 145, 93, 145, 94, 146, 99, 146, 96, 147, 101, 147, 98, 148, 99, 148, 100, 149, 101, 149, 102, 150, 103, 150, 104, 151, 105, 151, 106, 152, 107, 152, 108, 153, 109, 153, 106, 152, 107, 152, 108, 153, 109, 153, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 110, 154, 99, 154, 112, 155, 101, 155, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 94, 146, 99, 146, 100, 149, 101, 149, 122, 160, 99, 160, 124, 161, 101, 161, 90, 126, 91, 162, 92, 127, 93, 163, 94, 128, 99, 164, 96, 129, 101, 165, 98, 130, 99, 166, 100, 131, 101, 167, 102, 132, 103, 168, 104, 133, 105, 169, 106, 134, 107, 170, 108, 135, 109, 171, 106, 134, 107, 170, 108, 135, 109, 171, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 110, 136, 99, 172, 112, 137, 101, 173, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 94, 128, 99, 164, 100, 131, 101, 167, 122, 142, 99, 178, 124, 143, 101, 179, 90, 144, 91, 144, 92, 145, 93, 145, 94, 146, 99, 146, 96, 147, 101, 147, 98, 148, 99, 148, 100, 149, 101, 149, 102, 150, 103, 150, 104, 151, 105, 151, 106, 152, 107, 152, 108, 153, 109, 153, 106, 152, 107, 152, 108, 153, 109, 153, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 94, 146, 99, 146, 96, 147, 101, 147, 110, 154, 99, 154, 112, 155, 101, 155, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 114, 156, 99, 156, 116, 157, 101, 157, 118, 158, 99, 158, 120, 159, 101, 159, 94, 146, 99, 146, 100, 149, 101, 149, 122, 160, 99, 160, 124, 161, 101, 161, 90, 126, 91, 162, 92, 127, 93, 163, 94, 128, 99, 164, 96, 129, 101, 165, 98, 130, 99, 166, 100, 131, 101, 167, 102, 132, 103, 168, 104, 133, 105, 169, 106, 134, 107, 170, 108, 135, 109, 171, 106, 134, 107, 170, 108, 135, 109, 171, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 94, 128, 99, 164, 96, 129, 101, 165, 110, 136, 99, 172, 112, 137, 101, 173, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 114, 138, 99, 174, 116, 139, 101, 175, 118, 140, 99, 176, 120, 141, 101, 177, 94, 128, 99, 164, 100, 131, 101, 167, 122, 142, 99, 178, 124, 143, 101, 179,
}
var graphemesegmentationresult_t2 = [2880]GraphemeSegmentationResult{
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((0 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((0 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((1 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((0 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((0 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_AtStart) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_None) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Prepend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_CR) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LF) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Control) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Extend) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Regional_Indicator) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_SpacingMark) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_L) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_V) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_T) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LV) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_LVT) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_ZWJ) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((1 & 0b1) << 9),
	((GraphemeSegmentationResult(GBP_Private_Expecting_RI) & 0b1111) << 0) | ((1 & 0b1) << 4) | ((0 & 0b1) << 5) | ((1 & 0b1) << 6) | ((1 & 0b1) << 7) | ((1 & 0b1) << 8) | ((0 & 0b1) << 9),
}

// Array accessor function that avoids bounds checking
func graphemesegmentationresult_for(x uint16) GraphemeSegmentationResult {
	t1 := uintptr(*(*uint8)(unsafe.Pointer(uintptr(unsafe.Pointer(&graphemesegmentationresult_t1[0])) + uintptr(x>>graphemesegmentationresult_shift)*1)))
	t1_shifted := (t1 << graphemesegmentationresult_shift) + (uintptr(x) & graphemesegmentationresult_mask)
	return *(*GraphemeSegmentationResult)(unsafe.Pointer(uintptr(unsafe.Pointer(&graphemesegmentationresult_t2[0])) + t1_shifted*2))
}

func grapheme_segmentation_key(r GraphemeSegmentationResult, ch CharProps) uint16 {
	return (r.State() << 7) | ch.GraphemeSegmentationProperty()
}
